@@ -1,6 +1,6 @@
 /*
 qgvdial is a cross platform Google Voice Dialer
-Copyright (C) 2010  Yuvraaj Kelkar
+Copyright (C) 2009-2012  Yuvraaj Kelkar
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -206,8 +206,9 @@ GVApi::doGet(QUrl url, void *ctx, QObject *receiver, const char *method)
     QNetworkRequest req(url);
     req.setRawHeader("User-Agent", UA_IPHONE4);
 
-    req.setHeader (QNetworkRequest::CookieHeader,
-                   QVariant::fromValue(jar->getAllCookies ()));
+    QVariant var;
+    var.setValue (jar->getAllCookies ());
+    req.setHeader (QNetworkRequest::CookieHeader, var);
 
     QNetworkReply *reply = nwMgr.get(req);
     if (!reply) {
@@ -707,6 +708,7 @@ GVApi::onLogin2(bool success, const QByteArray &response, QNetworkReply *reply,
             if (docElemText.contains ("The username or password you entered "
                                       "is incorrect."))
             {
+                Q_WARN("Found Google's login failure string.");
                 break;
             }
 
@@ -1489,6 +1491,9 @@ GVApi::parseInboxJson(const QString &strJson, const QString &strHtml,
                 } else if (strPName == "messageText") {
                     inboxEntry.strText = strVal;
                 } else if (strPName == "hasMp3") {
+                    inboxEntry.vmailFormat = GVIVFMT_Mp3;
+                } else if (strPName == "hasOgg") {
+                    inboxEntry.vmailFormat = GVIVFMT_Ogg;
                 } else if (strPName == "duration") {
                     inboxEntry.vmailDuration = strVal.toInt ();
                 } else {
